mysql.stmt.bind_in.Base_Decimal

Package mysql :: Package stmt :: Module bind_in :: Class Base_Decimal |
[hide private]
[frames] | no frames]

# Class Base_Decimal

    object --+
             |
    Input_Bind --+
                 |
                Base_Decimal

Known Subclasses:
  In_Decimal, In_New_Decimal, In_U_Decimal, In_U_New_Decimal

Signed Decimal input binding.

Warning: Decimal input binding is broken in server versions 5.0.18 and older. See http://bugs.mysql.com/bug.php?id=16511

The value must be a `decimal.Decimal` object.

Instance Methods | [hide private]
`` | __init__(...) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
`` | __new__(T, S, ...) Returns a new object with type S, a subtype of T...
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`, `__str__`

Class Variables | [hide private]
`` | __pyx_vtable__ = `<PyCObject object at 0x852e770>`

Instance Variables | [hide private]
`` | _allow_negative Set to true in In_U_Decimal.
`` | _value The value as a string (in base-10).
Inherited from `Input_Bind` (private): `_buffer`, `_buffer_length`, `_buffer_type`, `_is_null`, `_is_unsigned`, `_length`, `_what`, `_who`

Properties | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(...) (Constructor) |
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: Input_Bind.__init__

### __new__(T, S, ...) |
    Returns:
        a new object with type S, a subtype of T
Overrides: Input_Bind.__new__

Class Variable Details | [hide private]

    ### __pyx_vtable__ Value:
        <PyCObject object at 0x852e770>

Instance Variable Details | [hide private]

### _allow_negative Set to true in In_U_Decimal. (C only.)

### _value The value as a string (in base-10). (C only.)